def active_tab(tab, sub_tab=None):
	def outer_wrapper(func):
        @wraps(func)
        def wrapper(request):
            request.nav = request.nav if hasattr(request, "nav") else {}
            request.nav["tab"] = tab
            if sub_tab is not None:
                request.nav["sub_tab"] = sub_tab
            return func(request)
        return wrapper

    return outer_wrapper



from distutils.core import setup	

setup(
	name='django-active-tab',
	version='0.0.1',
	description='nav decorator for django views',
	author='yangchen',
	author_email='yuhan534@126.com',
	url='https://github.com/jarvys.django-active-tab',
	install_requires=[
		'Django'
	],
	py_modules=['django_active_tab'],
	scripts=[],
	keywords=[
		'Django',
		'decorator',
		'view',
		'utilities'
	]
)

